@@ -15,17 +15,19 @@ except ModuleNotFoundError as e:
 
 class SpacyFactor(object):
     def __init__(
-        self,
-        issue_type: str,
-        simple_description: str,
-        description: Optional[str] = None,
-        debug=False,
+            self,
+            issue_type: str,
+            simple_description: str,
+            description: Optional[str] = None,
+            debug=False,
+            extended_span=False
     ):
         self.issue_type = issue_type
         self.simple_description = simple_description
         if description:
             self.description = description
         self.debug = debug
+        self.extended_span = extended_span
 
     @staticmethod
     def match_case(span: Span, suggestions):
@@ -56,7 +58,7 @@ class SpacyFactor(object):
                     # len condition is to exclude capitalization caused by "I"
                     suggestions = [s.upper() for s in suggestions]
                 elif (len(words[0]) > 1 and words[0][0].isupper()) or (
-                    is_sent_start and len(span[0]) == 1
+                        is_sent_start and len(span[0]) == 1
                 ):
                     # title case - first letter check & conversion due to contractions
                     for i, s in enumerate(suggestions):
@@ -73,12 +75,12 @@ class SpacyFactor(object):
         return suggestions
 
     def __call__(
-        self,
-        spacy_span: Span,
-        meta_subcategory=None,
-        describer=None,
-        cased=True,
-        v2=False,
+            self,
+            spacy_span: Span,
+            meta_subcategory=None,
+            describer=None,
+            cased=True,
+            v2=False,
     ):
         """
         convenient wrapper around make_issue if you are using spaCy
@@ -108,37 +110,39 @@ class SpacyFactor(object):
         ```
         """
         text, start, end = spacy_span.text, spacy_span.start_char, spacy_span.end_char
-        score = spacy_span._.score if spacy_span.has_extension("score") else 0
-        suggestions = (
-            spacy_span._.suggestions if spacy_span.has_extension("suggestions") else []
-        )
 
-        learn_more = (
-            spacy_span._.learn_more if spacy_span.has_extension("learn_more") else ""
-        )
-        paragraph = (
-            spacy_span._.paragraph if spacy_span.has_extension("paragraph") else False
-        )
-        header = spacy_span._.header if spacy_span.has_extension("header") else ""
-        meta_dict = (
-            spacy_span._.meta_dict if spacy_span.has_extension("meta_dict") else {}
-        )
-        visible = spacy_span._.visible if spacy_span.has_extension("visible") else True
-        # SIMPLE DESCRIPTION IS DIFFERENT, since it is set when initialized
-        # so we need to check that the span doesn't just have an empty value
-        simple_description = (
-            spacy_span._.simple_description
-            if (
-                spacy_span.has_extension("simple_description")
-                and spacy_span._.simple_description != ""
+        if not self.extended_span:
+            score = spacy_span._.score if spacy_span.has_extension("score") else 0
+            suggestions = (spacy_span._.suggestions if spacy_span.has_extension("suggestions") else [])
+            learn_more = (spacy_span._.learn_more if spacy_span.has_extension("learn_more") else "")
+            paragraph = (spacy_span._.paragraph if spacy_span.has_extension("paragraph") else False)
+            header = spacy_span._.header if spacy_span.has_extension("header") else ""
+            meta_dict = (spacy_span._.meta_dict if spacy_span.has_extension("meta_dict") else {})
+            visible = spacy_span._.visible if spacy_span.has_extension("visible") else True
+            # SIMPLE DESCRIPTION IS DIFFERENT, since it is set when initialized
+            # so we need to check that the span doesn't just have an empty value
+            simple_description = (
+                spacy_span._.simple_description
+                if (spacy_span.has_extension("simple_description") and spacy_span._.simple_description != "")
+                else self.simple_description
             )
-            else self.simple_description
-        )
-        accept_all_changes = (
-            spacy_span._.accept_all_changes
-            if spacy_span.has_extension("accept_all_changes")
-            else False
-        )
+            accept_all_changes = (
+                spacy_span._.accept_all_changes
+                if spacy_span.has_extension("accept_all_changes")
+                else False
+            )
+        else:
+            score = spacy_span.score
+            suggestions = spacy_span.suggestions
+            learn_more = spacy_span.learn_more
+            paragraph = spacy_span.paragraph
+            header = spacy_span.header
+            meta_dict = spacy_span.meta_dict
+            visible = spacy_span.visible
+            simple_description = (
+                spacy_span.simple_description if spacy_span.simple_description != "" else self.simple_description
+            )
+            accept_all_changes = spacy_span.accept_all_changes
 
         if cased:
             suggestions = self.match_case(spacy_span, suggestions)
@@ -170,7 +174,7 @@ class SpacyFactor(object):
             accept_all_changes=accept_all_changes,
             debug=self.debug,
             segment=spacy_span.doc.text,
-            visible=visible,
+            visible=visible
         )
         if v2:
             issue_to_v2(i)
