@@ -22,8 +22,10 @@ class Validator:
 
     def _is_unacceptable(self, segment: str):
         if self._is_empty(segment):
+            print("segment is empty")
             return True
         if self.ignore_html and self._has_html(segment):
+            print("segment has HTML")
             return True
         return False
 
@@ -33,7 +35,7 @@ class Validator:
     def _has_too_many_ignore_tokens(self, segment: str) -> bool:
         tokens = segment.strip().split(" ")
         token_length = len(tokens)
-        ignored_tokens = [self._is_ignored_tokens(t) for t in tokens]
+        ignored_tokens = [t for t in tokens if self._is_ignored_tokens(t)]
         ignored_length = len(ignored_tokens)
         if token_length == 0:
             return False
@@ -44,9 +46,9 @@ class Validator:
             )
 
     def __call__(self, segment: str):
-        is_valid = True
         if self._is_unacceptable(segment):
             return False
         if self._has_too_many_ignore_tokens(segment):
+            print(f"too many non-letter tokens in {segment}")
             return False
         return True
